pecos.slr.cops
==============

.. automodule:: pecos.slr.cops











   .. rubric:: Classes

   .. autosummary::

      AND
      AssignmentOp
      BinOp
      COp
      CompOp
      DIV
      EQUIV
      GE
      GT
      LE
      LSHIFT
      LT
      MINUS
      MUL
      NEG
      NEQUIV
      NOT
      OR
      PLUS
      PyCOp
      RSHIFT
      SET
      UnaryOp
      XOR
